@@ -4,7 +4,7 @@ package Data::Password;
 # Oded S. Resnik, 3 April 2004, for Raz Information Systems
 
 
-use Symbol;
+
 use strict;
 require Exporter;
 use vars qw($DICTIONARY $FOLLOWING $GROUPS $MINLEN $MAXLEN
@@ -16,7 +16,7 @@ use vars qw($DICTIONARY $FOLLOWING $GROUPS $MINLEN $MAXLEN
 %EXPORT_TAGS = ('all' => [@EXPORT_OK]);
 @ISA = qw(Exporter);
 
-$VERSION = '1.06';
+$VERSION = '1.08';
 
 $DICTIONARY = 5;
 $FOLLOWING = 3;
@@ -28,33 +28,35 @@ $MAXLEN = 8;
 @DICTIONARIES = qw(/usr/dict/web2 /usr/dict/words /usr/share/dict/words /usr/share/dict/linux.words);
 
 sub OpenDictionary {
-	my $sym = gensym;
-	foreach (@DICTIONARIES) {
-		return $sym if (open($sym, $_));
+	foreach my $sym (@DICTIONARIES) {
+		return $sym if -r $sym;
 	}
-	undef;
+	return;
 }
 
 sub CheckDict {
-	return undef unless $DICTIONARY;
+	return unless $DICTIONARY;
 	my $pass = shift;
 	my $dict = OpenDictionary();
-	return undef unless $dict;
-	while (<$dict>) {
-		chomp;
-		next if length($_) < $DICTIONARY;
-		next if $_ =~/\W/;
-		if ($pass =~ /$_/i) {
-			close($dict);
-			return $_;
+	return unless $dict;
+	open (DICT,"$dict") || return;
+        $pass = lc($pass);
+
+	while (my $dict_line  = <DICT>) {
+		chomp ($dict_line);
+		next if length($dict_line) < $DICTIONARY;
+		$dict_line = lc($dict_line);
+		if (index($pass,$dict_line)>-1) {
+			close(DICT);
+			return $dict_line;
 		}
 	}
-	close($dict);
-	undef;
+	close(DICT);
+	return;
 }
 
 sub CheckSort {
-	return undef unless $FOLLOWING;
+	return unless $FOLLOWING;
 	my $pass = shift;
 	foreach (1 .. 2) {
 		my @letters = split(//, $pass);
@@ -66,7 +68,7 @@ sub CheckSort {
 		}
 		my $len = $FOLLOWING - 1;
 		return 1 if $diffs =~ /([\@AB])\1{$len}/;
-		return undef unless $FOLLOWING_KEYBOARD;
+		return unless $FOLLOWING_KEYBOARD;
 
 		my $mask = $pass;
 		$pass =~ tr/A-Z/a-z/;
@@ -74,7 +76,7 @@ sub CheckSort {
 		$pass =~ tr/qwertyuiopasdfghjklzxcvbnm/abcdefghijKLMNOPQRStuvwxyz/;
 		$pass ^= $mask;
 	}
-	undef;
+	return;
 }
 
 sub CheckTypes {
@@ -98,7 +100,7 @@ sub CheckLength {
 	my $len = length($pass);
 	return 1 if ($MINLEN && $len < $MINLEN);
 	return 1 if ($MAXLEN && $len > $MAXLEN);
-	undef;
+	return;
 }
 
 sub IsBadPassword {
@@ -117,7 +119,7 @@ sub IsBadPassword {
 		if CheckSort($pass);
 	my $dict = CheckDict($pass);
 	return "contains the dictionary word '$dict'" if $dict;
-	undef;
+	return;
 }
 
 sub IsBadPasswordForUNIX {
@@ -130,11 +132,11 @@ sub IsBadPasswordForUNIX {
 
 	my ($name,$passwd,$uid,$gid,
        		$quota,$comment,$gcos,$dir,$shell,$expire) = getpwnam($user);
-	return undef unless $comment;
+	return unless $comment;
 	foreach ($comment =~ /([A-Z]+)/ig) {
 		return "is based on the finger information" if ($pass =~ /$_/i);
 	}
-	undef;
+	return;
 }
 
 1;
@@ -142,7 +144,7 @@ __END__
 
 =head1 NAME
 
-Data::Password - Perl extension for assesing password quality.
+Data::Password - Perl extension for assessing password quality.
 
 =head1 SYNOPSIS
 
@@ -162,10 +164,10 @@ Data::Password - Perl extension for assesing password quality.
 
 =head1 DESCRIPTION
 
-This modules checks potential passwords for crackability.
+This module checks potential passwords for crackability.
 It checks that the password is in the appropriate length,
 that it has enough character groups, that it does not contain the same 
-chars repeatedly or ascending or descending characters, or charcters
+characters repeatedly or ascending or descending characters, or charcters
 close to each other in the keyboard.
 It will also attempt to search the ispell word file for existance 
 of whole words.
@@ -261,16 +263,19 @@ set this variable if you are using not *NIX like operating system.
 =head1 SEE ALSO
 
 See L<Data::Password::BasicCheck> if you need only basic password checking.
+Other modules L<Data::Password::Common>, L<Data::Password::Check>,
+L<Data::Password::Meter>, L<Data::Password::Entropy> 
+and L<String::Validator::Password>
 
 
 =head1 AUTHOR
 
-Raz Information Systems, B<razinf@cpan.org>, B<raz@raz.co.il>.
+Raz Information Systems, B<razinf@cpan.org> 
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001 - 2006  Raz Information Systems Ltd.
-http://www.raz.co.il/
+Copyright (c) 2001 - 2013  Raz Information Systems Ltd.
+L<http://www.raz.co.il/>
 
 This package is distributed under the same terms as Perl itself, see the
 Artistic License on Perl's home page.
